# Deck Orientation & Jubilee Coordinate System

 The Laboratory Automation Bed Plate and well plates are oriented as follows:


![Lab Automation Bed plate & Wellplate Coordinate System ](../../docs/images/Automation_Deck_Orientation_Schematics.png)
